"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createWebDevServerPluginConfiguration = exports.initGenerator = exports.WEB_DEV_SERVER_PLUGIN_NAME = void 0;
const devkit_1 = require("@nx/devkit");
// TODO: import the package.json and read the name? :D
exports.WEB_DEV_SERVER_PLUGIN_NAME = '@robby-rabbitman/nx-plus-web-dev-server/plugin';
/**
 * 1. Adds `@robby-rabbitman/nx-plus-web-dev-server/plugin` to the `plugins` of the
 *    `nx.json` when not already included. Can be skipped with `skipAddPlugin`.
 * 2. Formats the updated files. Can be skipped with `skipFormat`.
 *
 * @param {WebDevServerInitGeneratorSchema} [schema.serveTargetName="serve"]
 *   Default is `"serve"`
 * @param {WebDevServerInitGeneratorSchema} [schema.skipAddPlugin=true] Default
 *   is `true`
 * @param {WebDevServerInitGeneratorSchema} [schema.skipFormat=true] Default is
 *   `true`
 */
const initGenerator = async (tree, schema) => {
    const defaultServeTargetName = 'serve';
    const options = {
        skipAddPlugin: false,
        skipFormat: false,
        serveTargetName: defaultServeTargetName,
        ...schema,
    };
    // make sure `serveTargetName` is not an empty string
    if (options.serveTargetName === '') {
        options.serveTargetName = defaultServeTargetName;
    }
    const { skipAddPlugin, skipFormat } = options;
    // 1.
    if (!skipAddPlugin) {
        const nxJson = (0, devkit_1.readNxJson)(tree);
        nxJson.plugins ??= [];
        const hasWebDevServerPlugin = nxJson.plugins.some((pluginConfig) => {
            // `pluginConfig` can be a string representing the plugin name or a object with a plugin property representing the plugin name
            if (typeof pluginConfig === 'string') {
                return pluginConfig === exports.WEB_DEV_SERVER_PLUGIN_NAME;
            }
            return pluginConfig.plugin === exports.WEB_DEV_SERVER_PLUGIN_NAME;
        });
        if (!hasWebDevServerPlugin) {
            nxJson.plugins.push((0, exports.createWebDevServerPluginConfiguration)({
                webDevServerPluginName: exports.WEB_DEV_SERVER_PLUGIN_NAME,
                options,
            }));
            (0, devkit_1.updateNxJson)(tree, nxJson);
        }
    }
    // 2.
    if (!skipFormat) {
        await (0, devkit_1.formatFiles)(tree);
    }
};
exports.initGenerator = initGenerator;
exports.default = exports.initGenerator;
const createWebDevServerPluginConfiguration = ({ options, webDevServerPluginName, }) => ({
    plugin: webDevServerPluginName,
    options: {
        serveTargetName: options.serveTargetName,
    },
});
exports.createWebDevServerPluginConfiguration = createWebDevServerPluginConfiguration;
//# sourceMappingURL=init.js.map