"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createNodesV2 = exports.createNodes = exports.WEB_DEV_SERVER_COMMAND = exports.WEB_DEV_SERVER_CONFIG_FILE_NAME_GLOB = void 0;
const devkit_1 = require("@nx/devkit");
const node_fs_1 = require("node:fs");
const node_path_1 = require("node:path");
exports.WEB_DEV_SERVER_CONFIG_FILE_NAME_GLOB = '**/@(web-dev-server|wds).config.@(js|cjs|mjs)';
exports.WEB_DEV_SERVER_COMMAND = 'web-dev-server';
// TODO: remove me in nx20
exports.createNodes = [
    exports.WEB_DEV_SERVER_CONFIG_FILE_NAME_GLOB,
    (webDevServerConfigPath, options, context) => createWebDevServerTarget(webDevServerConfigPath, options, context),
];
// TODO: rename me in nx21
exports.createNodesV2 = [
    exports.WEB_DEV_SERVER_CONFIG_FILE_NAME_GLOB,
    (webDevServerConfigPaths, options, context) => {
        return (0, devkit_1.createNodesFromFiles)(createWebDevServerTarget, webDevServerConfigPaths, options, context);
    },
];
/**
 * Helper function for `createNodes`.
 *
 * 1. Checks whether `webDevServerConfigPath` is considered a non root project, if
 *    not returns without modifying the project graph.
 * 2. Adds a _serve_ target, which calls the `web-dev-server` cli in the project
 *    root when executed. Merges `schema.serveTargetConfig` into this target.
 *
 * @param webDevServerConfigPath Relative to `context.workspaceRoot` e.g
 *   `'path/to/web-dev-server.config.js'`
 * @param schema Of `createNodes`
 * @param context Of `createNodes`
 * @returns
 */
const createWebDevServerTarget = (webDevServerConfigPath, schema, context) => {
    const defaultServeTargetName = 'serve';
    const options = {
        serveTargetName: defaultServeTargetName,
        serveTargetConfig: {},
        ...schema,
    };
    // make sure `serveTargetName` is not an empty string
    if (options.serveTargetName === '') {
        options.serveTargetName = defaultServeTargetName;
    }
    const { serveTargetName, serveTargetConfig } = options;
    const webDevServerConfigFileName = (0, node_path_1.basename)(webDevServerConfigPath);
    const maybeWebDevServerProjectRoot = (0, node_path_1.dirname)(webDevServerConfigPath);
    // 1.
    if (!isNonRootProject(maybeWebDevServerProjectRoot, context)) {
        return {};
    }
    const webDevServerProjectRoot = maybeWebDevServerProjectRoot;
    // 2.
    const webDevServerConfiguration = {
        config: webDevServerConfigFileName,
        watch: true,
    };
    const webDevServerTargetConfiguration = {
        command: exports.WEB_DEV_SERVER_COMMAND,
        ...serveTargetConfig,
        options: {
            ...webDevServerConfiguration,
            cwd: '{projectRoot}',
            ...serveTargetConfig.options,
        },
    };
    return {
        projects: {
            [webDevServerProjectRoot]: {
                targets: {
                    [serveTargetName]: webDevServerTargetConfiguration,
                },
            },
        },
    };
};
/**
 * Helper function for `createNodes`.
 *
 * https://nx.dev/extending-nx/recipes/project-graph-plugins#identifying-projects
 *
 * @param directory Relative to `context.workspaceRoot` e.g `'path/to/project'`
 * @returns Whether `directory` is considered a non root project => `directory`
 *   is not `context.workspaceRoot` and has a `project.json` or `package.json`
 */
const isNonRootProject = (directory, context) => {
    if (directory === '.')
        return false;
    return ((0, node_fs_1.existsSync)((0, node_path_1.join)(context.workspaceRoot, directory, 'project.json')) ||
        (0, node_fs_1.existsSync)((0, node_path_1.join)(context.workspaceRoot, directory, 'package.json')));
};
//# sourceMappingURL=plugin.js.map